from fastapi import APIRouter

from src.errors import Response
from src.types.animals import Animal
from src.utils import load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

animals = APIRouter(prefix='/animals', tags=['Animals'])


@animals.get('/')
async def get_animals(query_field: str = 'names', query_languages: str = 'eng') -> Response:
    query_langs = parse_query_langs(query_languages)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'animals')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@animals.get('/{query}')
async def get_animal(query: str, query_languages: str = 'eng', result_language: str = 'ru') -> Response[Animal]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'animals', query_langs)
    print(filename)
    return Response[Animal](response=load_category(result_lang, 'animals', filename))
