from fastapi import APIRouter
from subprocess import check_output

from src.constants import GAME_VERSION, SERVER_VERSION, LANGUAGES
from src.errors import Response

api = APIRouter(prefix='/api', tags=['Service'])


@api.get('/version')
async def get_versions():
    git_server = git_info('.')
    git_data = git_info('./data')

    response = {'server_version': SERVER_VERSION,
                'game_version': GAME_VERSION,
                'git_server': git_server,
                'git_data': git_data}

    return Response(response=response)


@api.get('/languages')
async def get_languages():
    return Response(response=LANGUAGES)


def git_info(path: str):
    data_hash = git_revision_hash(path)
    git = {
        'commit': git_revision_short_hash(path),
        'commit_hash': data_hash,
        'branch': git_branch(path),
        'release': git_text(data_hash, path)
    }
    return git


def git_revision_short_hash(cwd=None) -> str:
    return check_out(['git', 'rev-parse', '--short', 'HEAD'], cwd)


def git_revision_hash(cwd=None) -> str:
    return check_out(['git', 'rev-parse', 'HEAD'], cwd)


def git_branch(cwd=None) -> str:
    return check_out(['git', 'branch', '--show-current'], cwd)


def git_text(commit, cwd=None) -> str:
    return check_out(['git', 'log', '--format=%B', '-n', '1', commit], cwd)


def check_out(args, cwd=None):
    if not cwd:
        cwd = './'
    return check_output(args, cwd=cwd).decode('ascii').strip()
