from fastapi import APIRouter

from src.errors import Response
from src.types.artifacts import Artifact
from src.utils import load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

artifacts = APIRouter(prefix='/artifacts', tags=['Artifacts'])


@artifacts.get('/')
async def get_artifacts(query_field: str = 'names', query_languages: str = 'eng') -> Response:
    query_langs = parse_query_langs(query_languages)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'artifacts')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@artifacts.get('/{query}')
async def get_artifact(query: str, query_languages: str = 'eng', result_language: str = 'ru') -> Response[Artifact]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'artifacts', query_langs)
    return Response[Artifact](response=load_category(result_lang, 'artifacts', filename))
