from fastapi import APIRouter

from src.errors import Response
from src.types.domains import Domain
from src.utils import load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

domains = APIRouter(prefix='/domains', tags=['Domains'])


@domains.get('/')
async def get_domains(query_field: str = 'names', query_languages: str = 'eng') -> Response:
    query_langs = parse_query_langs(query_languages)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'domains')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@domains.get('/{query}', response_model_exclude_none=True)
async def get_domain(query: str, query_languages: str = 'eng', result_language: str = 'ru') -> Response[Domain]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'domains', query_langs)
    return Response[Domain](response=load_category(result_lang, 'domains', filename))
