from fastapi import APIRouter

from src.errors import Response
from src.types.elements import Element
from src.utils import load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

elements = APIRouter(prefix='/elements', tags=['Elements'])


@elements.get('/')
async def query_elements(query_field: str = 'names', query_languages: str = 'eng') -> Response:
    query_langs = parse_query_langs(query_languages)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'elements')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@elements.get('/{query}')
async def query_element(query: str, query_languages: str = 'eng', result_language: str = 'ru') -> Response[Element]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'elements', query_langs)
    return Response[Element](response=load_category(result_lang, 'elements', filename))
