from fastapi import APIRouter

from src.errors import Response
from src.types.enemies import Enemy
from src.utils import load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

enemies = APIRouter(prefix='/enemies', tags=['Enemies'])


@enemies.get('/')
async def get_enemies(query_field: str = 'names', query_languages: str = 'eng') -> Response:
    query_langs = parse_query_langs(query_languages)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'enemies')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@enemies.get('/{query}', response_model_exclude_none=True)
async def get_enemy(query: str, query_languages: str = 'eng', result_language: str = 'ru') -> Response[Enemy]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'enemies', query_langs)
    return Response[Enemy](response=load_category(result_lang, 'enemies', filename))
