from fastapi import APIRouter

from src.errors import Response
from src.types.namecards import NameCard
from src.utils import load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

namecards = APIRouter(prefix='/namecards', tags=['Namecards'])


@namecards.get('/')
async def get_namecards(query_field: str = 'names', result_language: str = 'eng') -> Response:
    query_langs = parse_query_langs(result_language)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'namecards')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@namecards.get('/{query}', response_model_exclude_none=True)
async def get_namecard(query: str, query_languages: str = 'eng', result_language: str = 'ru') -> Response[NameCard]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'namecards', query_langs)
    return Response[NameCard](response=load_category(result_lang, 'namecards', filename))
