from fastapi import APIRouter

from src.errors import Response
from src.types.outfits import Outfit
from src.utils import load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

outfits = APIRouter(prefix='/outfits', tags=['Outfits'])


@outfits.get('/')
async def get_outfits(query_field: str = 'names', result_language: str = 'eng') -> Response:
    query_langs = parse_query_langs(result_language)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'outfits')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@outfits.get('/{query}', response_model_exclude_none=True)
async def get_outfit(query: str, query_languages: str = 'eng', result_language: str = 'ru') -> Response[Outfit]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'outfits', query_langs)
    return Response[Outfit](response=load_category(result_lang, 'outfits', filename))
