from fastapi import APIRouter

from src.errors import Response
from src.types.talentmaterialtypes import TalentMaterialType
from src.utils import load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

talent_material_types = APIRouter(prefix='/talent_material_type', tags=['Talent Material'])


@talent_material_types.get('/')
async def get_talent_material_types(query_field: str = 'names', result_language: str = 'eng') -> Response:
    query_langs = parse_query_langs(result_language)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'talentmaterialtypes')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@talent_material_types.get('/{query}', response_model_exclude_none=True)
async def get_talent_material_type(
        query: str, query_languages: str = 'eng', result_language: str = 'ru'
) -> Response[TalentMaterialType]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'talentmaterialtypes', query_langs)
    return Response[TalentMaterialType](response=load_category(result_lang, 'talentmaterialtypes', filename))
