from fastapi import APIRouter

from src.errors import Response
from src.types.weapons import Weapon
from src.utils import load_file, load_index, parse_query_langs, parse_result_lang, load_category, get_file_name

weapons = APIRouter(prefix='/weapons', tags=['Weapons'])


@weapons.get('/')
async def get_weapons(query_field: str = 'names', result_language: str = 'eng') -> Response:
    query_langs = parse_query_langs(result_language)
    response: list[dict[str, list[str]]] = []
    for query_lang in query_langs:
        chars = load_index(query_lang, 'weapons')
        response.append({query_lang: list(chars[query_field].keys())})
    return Response[list[dict[str, list[str]]]](error=False, response=response)


@weapons.get('/{query}', response_model_exclude_none=True)
async def get_weapon(
    query: str, query_languages: str = 'eng', result_language: str = 'ru',
    images: bool = False, stats: bool = False, url: bool = False
) -> Response[Weapon]:
    query_langs = parse_query_langs(query_languages)
    result_lang = parse_result_lang(result_language)
    filename = get_file_name(query, 'weapons', query_langs)

    response = load_category(result_lang, 'weapons', filename)
    if images:
        images_file = load_file('image', 'weapons')
        response.update({'images': images_file[filename]})
    if stats:
        stats_file = load_file('stats', 'weapons')
        response.update({'stats': stats_file[filename]})
    if url:
        url_file = load_file('url', 'weapons')
        response.update({'url': url_file[filename]})

    version_file = load_file('version', 'weapons')
    response.update({'version': version_file[filename]})

    return Response[Weapon](response=response)
