from json import load, loads, dumps
from os import environ
from os.path import join

from dotenv import load_dotenv
from fastapi import HTTPException
from memcache import Client

from src.constants import LANGUAGES, DEFAULT_RESULT, DEFAULT_QUERY, DATA_FOLDER


load_dotenv()
memcache_ip = environ.get('MEMCACHE_IP')
memcache_port = environ.get('MEMCACHE_PORT') or 11211
mc = Client([f'{memcache_ip}:{memcache_port}'], debug=1)


def load_cached(key):
    value = mc.get(key)
    if not value:
        return None
    print(f'loaded {key} from cache')
    return loads(value)


def save_cache(key, value: str | dict):
    if type(value) is dict:
        mc.set(key, dumps(value), 86400)
    else:
        mc.set(key, value, 86400)


def load_index(language: str, category: str):
    cache_key = join('index', language, category)
    if cache := load_cached(cache_key):
        return cache
    with open(join(DATA_FOLDER, 'index', language, f'{category}.json'), 'r', encoding='utf-8') as f:
        json = f.read()
        save_cache(cache_key, json)
        return loads(json)


def load_category(lang: str, category: str, name: str) -> dict:
    cache_key = join(lang, category, name)
    if cache := load_cached(cache_key):
        return cache
    with open(join(DATA_FOLDER, lang, category, f'{name}.json'), 'r', encoding='utf-8') as f:
        json = f.read()
        save_cache(cache_key, json)
        return loads(json)


def load_file(folder: str, name: str) -> dict:
    cache_key = join(folder, name)
    if cache := load_cached(cache_key):
        return cache
    with open(join(DATA_FOLDER, folder, f'{name}.json'), 'r', encoding='utf-8') as f:
        json = f.read()
        save_cache(cache_key, json)
        return loads(json)


def get_file_name(query, category, langs) -> str:
    for lang in langs:
        index: dict[str, str] = load_index(lang, category)['names']
        
        for key, value in index.items():
            for k in key.lower().split(' '):
                if k.startswith(query.lower()):
                    return value
        else:
            raise HTTPException(404)


def parse_query_langs(langs: str) -> list[str]:
    languages = langs.replace(' ', '').split(',')
    query = []
    for i in languages:
        for j in LANGUAGES:
            if j.lower().startswith(i):
                query.append(j)
    return query if len(query) > 0 else DEFAULT_QUERY


def parse_result_lang(lang: str) -> str:
    for l in LANGUAGES:
        if l.lower().startswith(lang):
            return l
    else:
        return DEFAULT_RESULT
